@@ -20,6 +20,7 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
+from __future__ import annotations
 
 
 import sys
@@ -73,12 +74,51 @@ def stop_autoclose():
         _laz.subprocess.run("pause", shell=True)
 
 
-def parse_args(args):
-    parser = _laz.argparse.ArgumentParser(
+def _get_parser_class():
+    # This class is deferred to avoid the argparse import
+    # if there are no arguments to parse
+
+    class FixedArgumentParser(_laz.argparse.ArgumentParser):
+        """
+        The builtin argument parser uses shutil to figure out the terminal width
+        to display help info. This one replaces the function that calls help info
+        and plugs in a value for width.
+
+        This prevents the unnecessary import.
+        """
+
+        def _get_formatter(self):
+            # Calculate width
+            try:
+                columns = int(os.environ['COLUMNS'])
+            except (KeyError, ValueError):
+                try:
+                    size = os.get_terminal_size()
+                except (AttributeError, ValueError, OSError):
+                    # get_terminal_size unsupported
+                    columns = 80
+                else:
+                    columns = size.columns
+
+            # noinspection PyArgumentList
+            return self.formatter_class(prog=self.prog, width=columns - 2)
+
+    return FixedArgumentParser
+
+
+def get_parser():
+    FixedArgumentParser = _get_parser_class()  # noqa
+
+    parser = FixedArgumentParser(
         prog="ducktools-pythonfinder",
         description="Discover base Python installs",
     )
     parser.add_argument("-V", "--version", action="version", version=__version__)
+    parser.add_argument(
+        "--fast",
+        action="store_true",
+        help="Skip Python installs that need to be launched to obtain metadata"
+    )
 
     subparsers = parser.add_subparsers(dest="command", required=False)
 
@@ -116,12 +156,15 @@ def parse_args(args):
         help="Include prerelease versions"
     )
 
-    vals = parser.parse_args(args)
-
-    return vals
+    return parser
 
 
-def display_local_installs(min_ver=None, max_ver=None, compatible=None):
+def display_local_installs(
+    min_ver=None,
+    max_ver=None,
+    compatible=None,
+    query_executables=True,
+):
     if min_ver:
         min_ver = tuple(int(i) for i in min_ver.split("."))
     if max_ver:
@@ -129,36 +172,27 @@ def display_local_installs(min_ver=None, max_ver=None, compatible=None):
     if compatible:
         compatible = tuple(int(i) for i in compatible.split("."))
 
-    installs = list_python_installs()
-    headings = ["Python Version", "Executable Location"]
-    max_executable_len = max(
-        len(headings[1]), max(len(inst.executable) for inst in installs)
-    )
-    headings_str = f"| {headings[0]} | {headings[1]:<{max_executable_len}s} |"
+    installs = list_python_installs(query_executables=query_executables)
 
-    print("Discoverable Python Installs")
-    if sys.platform == "win32":
-        print("+ - Listed in the Windows Registry ")
-        print("^ - This is a 32-bit Python install")
-    if sys.platform != "win32":
-        print("[] - This Python install is shadowed by another on Path")
-    print("* - This is the active Python executable used to call this module")
-    print("** - This is the parent Python executable of the venv used to call this module")
-    print()
-    print(headings_str)
-    print(f"| {'-' * len(headings[0])} | {'-' * max_executable_len} |")
+    headings = ["Version", "Executable Location"]
+
+    install_collection: list[tuple[str, str]] = []
+    max_version_len = len(headings[0])
+    max_executable_len = len(headings[1])
+
+    alternate_implementations = False
+
+    # First collect the strings
     for install in installs:
         if min_ver and install.version < min_ver:
             continue
         elif max_ver and install.version > max_ver:
             continue
         elif compatible:
-            mismatch = False
-            for i, val in enumerate(compatible):
-                if val != install.version[i]:
-                    mismatch = True
-                    break
-            if mismatch:
+            if install.version < compatible:
+                continue
+            version_parts = len(compatible) - 1
+            if install.version[:version_parts] > compatible[:-1]:
                 continue
 
         version_str = install.version_str
@@ -177,20 +211,54 @@ def display_local_installs(min_ver=None, max_ver=None, compatible=None):
         ):
             version_str = f"**{version_str}"
 
+        if install.metadata.get("freethreaded"):
+            version_str = f"{version_str}t"
+
         if install.shadowed:
             version_str = f"[{version_str}]"
 
-        print(f"| {version_str:>14s} | {install.executable:<{max_executable_len}s} |")
+        if (
+            install.implementation != "cpython"
+            and install.implementation_version != install.version
+        ):
+            alternate_implementations = True
+            version_str = f"({install.implementation_version_str}) {version_str}"
+
+        max_version_len = max(max_version_len, len(version_str))
+        max_executable_len = max(max_executable_len, len(install.executable))
+
+        install_collection.append((version_str, install.executable))
+
+    print("Discoverable Python Installs")
+    print()
+    if alternate_implementations:
+        print("Alternate implementation versions are listed in parentheses")
+
+    if sys.platform == "win32":
+        print("+ - Listed in the Windows Registry ")
+        print("^ - This is a 32-bit Python install")
+    if sys.platform != "win32":
+        print("[] - This Python install is shadowed by another on Path")
+    print("* - This is the active Python executable used to call this module")
+    print("** - This is the parent Python executable of the venv used to call this module")
+    print()
+
+    headings_str = f"| {headings[0]:<{max_version_len}s} | {headings[1]:<{max_executable_len}s} |"
+    print(headings_str)
+    print(f"| {'-' * max_version_len} | {'-' * max_executable_len} |")
+
+    for version_str, executable in install_collection:
+        print(f"| {version_str:>{max_version_len}s} | {executable:<{max_executable_len}s} |")
 
 
 def display_remote_binaries(
-        min_ver,
-        max_ver,
-        compatible,
-        all_binaries,
-        system,
-        machine,
-        prerelease
+    min_ver,
+    max_ver,
+    compatible,
+    all_binaries,
+    system,
+    machine,
+    prerelease
 ):
     specs = []
     if min_ver:
@@ -234,7 +302,8 @@ def main():
         )
 
     if sys.argv[1:]:
-        vals = parse_args(sys.argv[1:])
+        parser = get_parser()
+        vals = parser.parse_args(sys.argv[1:])
 
         if vals.command == "online":
             system = vals.system if vals.system else _laz.platform.system()
@@ -252,7 +321,12 @@ def main():
             except _laz.URLError:
                 print("Could not connect to python.org")
         else:
-            display_local_installs(vals.min, vals.max, vals.compatible)
+            display_local_installs(
+                min_ver=vals.min,
+                max_ver=vals.max,
+                compatible=vals.compatible,
+                query_executables=not vals.fast,
+            )
     else:
         # No arguments to parse
         display_local_installs()
