@@ -33,7 +33,7 @@ from _collections_abc import Iterator
 
 from ducktools.lazyimporter import LazyImporter, ModuleImport
 
-from ..shared import PythonInstall, get_install_details
+from ..shared import PythonInstall, get_install_details, FULL_PY_VER_RE, version_str_to_tuple
 
 _laz = LazyImporter(
     [
@@ -41,35 +41,44 @@ _laz = LazyImporter(
     ]
 )
 
-# pyenv folder names
-PYTHON_VER_RE = r"\d{1,2}\.\d{1,2}\.\d+[a-z]*\d*"
+# pyenv folder name for pypy
 PYPY_VER_RE = r"^pypy(?P<pyversion>\d{1,2}\.\d+)-(?P<pypyversion>[\d\.]*)$"
 
-# 'pypy -V' output matcher
-PYPY_V_OUTPUT = (
-    r"(?is)python (?P<python_version>\d+\.\d+\.\d+[a-z]*\d*).*?"
-    r"pypy (?P<pypy_version>\d+\.\d+\.\d+[a-z]*\d*).*"
-)
-
 PYENV_VERSIONS_FOLDER = os.path.join(os.environ.get("PYENV_ROOT", ""), "versions")
 
 
 def get_pyenv_pythons(
     versions_folder: str | os.PathLike = PYENV_VERSIONS_FOLDER,
+    *,
+    query_executables: bool = True,
 ) -> Iterator[PythonInstall]:
     if not os.path.exists(versions_folder):
         return
 
-    # Sorting puts standard python versions before pypy
+    # Sorting puts standard python versions before alternate implementations
     # This can lead to much faster returns by potentially yielding
-    # the required python version before checking pypy
+    # the required python version before checking pypy/graalpy/micropython
 
     for p in sorted(os.scandir(versions_folder), key=lambda x: x.path):
         executable = os.path.join(p.path, "bin/python")
 
         if os.path.exists(executable):
-            if _laz.re.fullmatch(PYTHON_VER_RE, p.name):
-                yield PythonInstall.from_str(p.name, executable)
-            elif _laz.re.fullmatch(PYPY_VER_RE, p.name):
-                if install := get_install_details(executable):
-                    yield install
+            if p.name.endswith("t"):
+                freethreaded = True
+                version = p.name[:-1]
+            else:
+                freethreaded = False
+                version = p.name
+            if _laz.re.fullmatch(FULL_PY_VER_RE, version):
+                version_tuple = version_str_to_tuple(version)
+                metadata = {}
+                if version_tuple >= (3, 13):
+                    metadata["freethreaded"] = freethreaded
+                yield PythonInstall(
+                    version=version_tuple,
+                    executable=executable,
+                    metadata=metadata,
+                    managed_by="pyenv",
+                )
+            elif query_executables and (install := get_install_details(executable, managed_by="pyenv")):
+                yield install
