@@ -28,24 +28,33 @@ import os.path
 
 from _collections_abc import Iterator
 
-from ducktools.classbuilder import slotclass, Field, SlotFields
+from ducktools.classbuilder.prefab import Prefab, attribute
 from ducktools.lazyimporter import LazyImporter, ModuleImport, FromImport
 
 from . import details_script
 
 _laz = LazyImporter(
     [
-        ModuleImport("re"),
-        ModuleImport("subprocess"),
-        ModuleImport("platform"),
         FromImport("glob", "glob"),
         ModuleImport("json"),
+        ModuleImport("platform"),
+        ModuleImport("re"),
+        ModuleImport("subprocess"),
+        ModuleImport("tempfile"),
         ModuleImport("zipfile"),
     ]
 )
 
 
-FULL_PY_VER_RE = r"(?P<major>\d+)\.(?P<minor>\d+)\.?(?P<micro>\d*)(?P<releaselevel>[a-zA-Z]*)(?P<serial>\d*)"
+FULL_PY_VER_RE = r"(?P<major>\d+)\.(?P<minor>\d+)\.?(?P<micro>\d*)-?(?P<releaselevel>a|b|c|rc)?(?P<serial>\d*)?"
+
+UV_PYTHON_RE = (
+    r"(?P<implementation>[a-zA-Z]+)"
+    r"-(?P<version>\d+\.\d+\.\d*[a-zA-Z]*\d*)\+?(?P<extra>.*?)?"
+    r"-(?P<platform>\w*)"
+    r"-(?P<arch>\w*)"
+    r"-.*"
+)
 
 
 def version_str_to_tuple(version):
@@ -56,11 +65,11 @@ def version_str_to_tuple(version):
 
     major, minor, micro, releaselevel, serial = parsed_version.groups()
 
-    if releaselevel == "a":
+    if releaselevel in {"a", "dev"}:
         releaselevel = "alpha"
     elif releaselevel == "b":
         releaselevel = "beta"
-    elif releaselevel == "rc":
+    elif releaselevel in {"c", "rc"}:
         releaselevel = "candidate"
     else:
         releaselevel = "final"
@@ -87,7 +96,7 @@ def version_tuple_to_str(version_tuple):
     else:
         releaselevel = ""
 
-    if serial == 0:
+    if serial == 0 or not releaselevel:
         serial = ""
     else:
         serial = f"{serial}"
@@ -95,17 +104,12 @@ def version_tuple_to_str(version_tuple):
     return f"{major}.{minor}.{micro}{releaselevel}{serial}"
 
 
-@slotclass
-class DetailsScript:
+class DetailsScript(Prefab):
     """
     Class to obtain and cache the source code of details_script.py
     to use on external Pythons.
     """
-    __slots__ = SlotFields(
-        _source_code=Field(default=None)
-    )
-
-    _source_code: str | None
+    _source_code: str | None = attribute(default=None, private=True)
 
     def get_source_code(self):
         if self._source_code is None:
@@ -128,27 +132,48 @@ class DetailsScript:
 details = DetailsScript()
 
 
-@slotclass
-class PythonInstall:
-    __slots__ = SlotFields(
-        version=Field(),
-        executable=Field(),
-        architecture="64bit",
-        implementation="cpython",
-        metadata=Field(default_factory=dict),
-        shadowed=False,
-    )
+class PythonInstall(Prefab):
     version: tuple[int, int, int, str, int]
     executable: str
-    architecture: str
-    implementation: str
-    metadata: dict
-    shadowed: bool
+    architecture: str = "64bit"
+    implementation: str = "cpython"
+    managed_by: str | None = None
+    metadata: dict = attribute(default_factory=dict)
+    shadowed: bool = False
+    _implementation_version: tuple[int, int, int, str, int] | None = attribute(default=None, private=True)
+
+    def __prefab_post_init__(
+        self,
+        version: tuple[int, int, int] | tuple[int, int, int, str, int]
+    ):
+        if len(version) == 3:
+            # Micropython gives an invalid 3 part version here
+            # Add the extras to avoid breaking
+            self.version = tuple([*version, "final", 0])  # type: ignore
+        else:
+            self.version = version
 
     @property
     def version_str(self) -> str:
         return version_tuple_to_str(self.version)
 
+    @property
+    def implementation_version(self) -> tuple[int, int, int, str, int] | None:
+        if self._implementation_version is None:
+            if implementation_ver := self.metadata.get(f"{self.implementation}_version"):
+                if len(implementation_ver) == 3:
+                    self._implementation_version = tuple([*implementation_ver, "final", 0])  # type: ignore
+                else:
+                    self._implementation_version = implementation_ver
+            else:
+                self._implementation_version = self.version
+
+        return self._implementation_version
+
+    @property
+    def implementation_version_str(self) -> str:
+        return version_tuple_to_str(self.implementation_version)
+
     @classmethod
     def from_str(
         cls,
@@ -156,6 +181,7 @@ class PythonInstall:
         executable: str,
         architecture: str = "64bit",
         implementation: str = "cpython",
+        managed_by: str | None = None,
         metadata: dict | None = None,
     ):
         version_tuple = version_str_to_tuple(version)
@@ -166,16 +192,23 @@ class PythonInstall:
             executable=executable,
             architecture=architecture,
             implementation=implementation,
+            managed_by=managed_by,
             metadata=metadata,
         )
 
     @classmethod
-    def from_json(cls, version, executable, architecture, implementation, metadata):
+    def from_json(cls, version, executable, architecture, implementation, metadata, managed_by=None):
         if arch_ver := metadata.get(f"{implementation}_version"):
             metadata[f"{implementation}_version"] = tuple(arch_ver)
 
+        # noinspection PyArgumentList
         return cls(
-            tuple(version), executable, architecture, implementation, metadata  # noqa
+            version=tuple(version),
+            executable=executable,
+            architecture=architecture,
+            implementation=implementation,
+            managed_by=managed_by,
+            metadata=metadata,
         )
 
     def get_pip_version(self) -> str | None:
@@ -205,7 +238,7 @@ def _python_exe_regex(basename: str = "python"):
         return _laz.re.compile(rf"{basename}\d?\.?\d*")
 
 
-def get_install_details(executable: str) -> PythonInstall | None:
+def get_install_details(executable: str, managed_by=None) -> PythonInstall | None:
     try:
         source = details.get_source_code()
     except FileNotFoundError:
@@ -219,15 +252,34 @@ def get_install_details(executable: str) -> PythonInstall | None:
             text=True,
             check=True,
         ).stdout
-    except (_laz.subprocess.CalledProcessError, FileNotFoundError):
+    except OSError:
+        # Something else has gone wrong
         return None
+    except (_laz.subprocess.CalledProcessError, FileNotFoundError):
+        # Potentially this is micropython which does not support
+        # piping from stdin. Try using a file in a temporary folder.
+        # Python 3.12 has delete_on_close that would make TemporaryFile
+        # Usable on windows but for now use a directory
+        with _laz.tempfile.TemporaryDirectory() as tempdir:
+            temp_script = os.path.join(tempdir, "details_script.py")
+            with open(temp_script, "w") as f:
+                f.write(source)
+            try:
+                detail_output = _laz.subprocess.run(
+                    [executable, temp_script],
+                    capture_output=True,
+                    text=True,
+                    check=True,
+                ).stdout
+            except (_laz.subprocess.CalledProcessError, FileNotFoundError):
+                return None
 
     try:
         output = _laz.json.loads(detail_output)
-    except _laz.json.JSONDecodeError:
+    except _laz.json.JSONDecodeError as e:
         return None
 
-    return PythonInstall.from_json(**output)
+    return PythonInstall.from_json(**output, managed_by=managed_by)
 
 
 def get_folder_pythons(
@@ -238,12 +290,24 @@ def get_folder_pythons(
 
     with os.scandir(base_folder) as fld:
         for file_path in fld:
+            try:
+                is_file = file_path.is_file()
+            except PermissionError:
+                continue
+            
             if (
-                not file_path.is_symlink()
-                and file_path.is_file()
+                is_file
                 and any(reg.fullmatch(file_path.name) for reg in regexes)
             ):
-                install = get_install_details(file_path.path)
+                p = file_path.path
+                if file_path.is_symlink():
+                    # Might be a venv - look for pyvenv.cfg in parent
+                    fld = os.path.dirname(p)
+                    if os.path.exists(os.path.join(fld, "../pyvenv.cfg")):
+                        continue
+                else:
+                    p = file_path.path
+                install = get_install_details(p)
                 if install:
                     yield install
 
@@ -257,7 +321,7 @@ def get_uv_python_path() -> str | None:
             text=True,
             capture_output=True
         )
-    except _laz.subprocess.CalledProcessError:
+    except (_laz.subprocess.CalledProcessError, FileNotFoundError):
         uv_python_dir = None
     else:
         # remove newline
@@ -266,39 +330,54 @@ def get_uv_python_path() -> str | None:
     return uv_python_dir
 
 
-def _implementation_from_uv_dir(direntry: os.DirEntry) -> PythonInstall | None:
+def _implementation_from_uv_dir(
+    direntry: os.DirEntry,
+    query_executables: bool = True,
+) -> PythonInstall | None:
     python_exe = "python.exe" if sys.platform == "win32" else "bin/python"
     python_path = os.path.join(direntry, python_exe)
 
     install: PythonInstall | None = None
 
     if os.path.exists(python_path):
-        try:
-            implementation, version, platform, arch, _ = direntry.name.split("-")
-        except ValueError:
-            # Directory name format has changed
+        if match := _laz.re.fullmatch(UV_PYTHON_RE, direntry.name):
+            implementation, version, extra, platform, arch = match.groups()
+            metadata = {
+                "freethreaded": "freethreaded" in extra,
+            }
+
+            try:
+                if implementation in {"cpython"}:
+                    install = PythonInstall.from_str(
+                        version=version,
+                        executable=python_path,
+                        architecture="32bit" if arch in {"i686", "armv7"} else "64bit",
+                        implementation=implementation,
+                        metadata=metadata,
+                        managed_by="Astral UV",
+                    )
+            except ValueError:
+                pass
+
+        if install is None:
+            # Directory name format has changed or this is an alternate implementation
             # Slow backup - ask python itself
-            install = get_install_details(python_path)
-        else:
-            if implementation == "cpython":
-                install = PythonInstall.from_str(
-                    version=version,
-                    executable=python_path,
-                    architecture="32bit" if arch in {"i686", "armv7"} else "64bit",
-                    implementation=implementation,
-                )
-            else:
-                # Get additional alternate implementation details
+            if query_executables:
                 install = get_install_details(python_path)
+                install.managed_by = "Astral UV"
 
     return install
 
 
-def get_uv_pythons() -> Iterator[PythonInstall]:
+def get_uv_pythons(query_executables=True) -> Iterator[PythonInstall]:
     # This takes some shortcuts over the regular pythonfinder
     # As the UV folders give the python version and the implementation
     if uv_python_path := get_uv_python_path():
-        with os.scandir(uv_python_path) as fld:
-            for f in fld:
-                if f.is_dir() and (install := _implementation_from_uv_dir(f)):
-                    yield install
+        if os.path.exists(uv_python_path):
+            with os.scandir(uv_python_path) as fld:
+                for f in fld:
+                    if (
+                        f.is_dir()
+                        and (install := _implementation_from_uv_dir(f, query_executables))
+                    ):
+                        yield install
