@@ -30,12 +30,12 @@ from .pyenv_search import get_pyenv_pythons
 from .registry_search import get_registered_pythons
 
 
-def get_python_installs() -> Iterator[PythonInstall]:
+def get_python_installs(*, query_executables: bool = True) -> Iterator[PythonInstall]:
     listed_installs = set()
     for py in itertools.chain(
         get_registered_pythons(),
-        get_pyenv_pythons(),
-        get_uv_pythons(),
+        get_pyenv_pythons(query_executables=query_executables),
+        get_uv_pythons(query_executables=query_executables),
     ):
         if py.executable not in listed_installs:
             yield py
