@@ -72,7 +72,7 @@ def test_mock_versions_folder():
 
         python_versions = list(get_pyenv_pythons())
 
-    assert python_versions == [PythonInstall.from_str(out_ver, out_executable)]
+    assert python_versions == [PythonInstall.from_str(version=out_ver, executable=out_executable, managed_by="pyenv")]
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Test for Windows only")
@@ -89,7 +89,7 @@ def test_fs_versions_win(fs):
 
     versions = list(get_pyenv_pythons(tmpdir))
 
-    assert versions == [PythonInstall.from_str("3.12.1", py_exe)]
+    assert versions == [PythonInstall.from_str(version="3.12.1", executable=py_exe, managed_by="pyenv")]
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Test for Windows only")
@@ -106,34 +106,38 @@ def test_32bit_version(fs):
 
     versions = list(get_pyenv_pythons(tmpdir))
 
-    assert versions == [PythonInstall.from_str("3.12.1", py_exe, architecture="32bit")]
+    assert versions == [
+        PythonInstall.from_str(version="3.12.1", executable=py_exe, architecture="32bit", managed_by="pyenv")
+    ]
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Test for Windows only")
-def test_invalid_ver_win(fs):
+def test_invalid_ver_win(fs, uses_details_script):
     # Ignore non-standard versions
 
-    tmpdir = "c:\\fake_folder"
+    pyenv_fld = "C:\\Fake_Folder"
 
-    py_folder = os.path.join(tmpdir, "external-python3.12.1")
+    py_folder = os.path.join(pyenv_fld, "external-python3.12.1")
     py_exe = os.path.join(py_folder, "python.exe")
 
     fs.create_dir(py_folder)
     fs.create_file(py_exe)
 
-    py2_folder = os.path.join(tmpdir, "ext3.13.0")
+    py2_folder = os.path.join(pyenv_fld, "ext3.13.0")
     py2_exe = os.path.join(py2_folder, "python.exe")
 
     fs.create_dir(py2_folder)
     fs.create_file(py2_exe)
 
-    py3_folder = os.path.join(tmpdir, "invalid-version-3.12.1")
+    py3_folder = os.path.join(pyenv_fld, "invalid-version-3.12.1")
     py3_exe = os.path.join(py3_folder, "python.exe")
 
     fs.create_dir(py3_folder)
     fs.create_file(py3_exe)
 
-    versions = list(get_pyenv_pythons(tmpdir))
+    with patch("subprocess.run") as run_mock:
+        versions = list(get_pyenv_pythons(pyenv_fld))
+        run_mock.assert_not_called()
 
     assert versions == []
 
@@ -153,11 +157,11 @@ def test_fs_versions_nix(fs):
 
     versions = list(get_pyenv_pythons(tmpdir))
 
-    assert versions == [PythonInstall.from_str("3.12.1", py_exe)]
+    assert versions == [PythonInstall.from_str(version="3.12.1", executable=py_exe, managed_by="pyenv")]
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Test for non-Windows only")
-def test_invalid_ver_nix(fs):
+def test_invalid_ver_nix(fs, uses_details_script):
     # Test folders in fake file system
 
     tmpdir = "~/.pyenv/versions"
@@ -183,7 +187,10 @@ def test_invalid_ver_nix(fs):
     fs.create_dir(os.path.join(py3_folder, "bin"))
     fs.create_file(py3_exe)
 
-    versions = list(get_pyenv_pythons(tmpdir))
+    with patch("subprocess.run") as run_mock:
+        run_mock.side_effect = OSError("Failure")
+        versions = list(get_pyenv_pythons(tmpdir))
+        assert run_mock.call_count == 3
 
     assert versions == []
 
@@ -230,6 +237,7 @@ def test_pypy_version(fs):
             architecture="64bit",
             implementation="pypy",
             metadata={"pypy_version": (7, 3, 15, "final", 0)},
+            managed_by="pyenv",
         )
 
         assert versions == [out_version]
